==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/WebRecordValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldValidationStateDescriptionMetadata } from "./WebFieldValidationStateDescriptionMetadata";
import { WebGridValidationStateDescriptionMetadata } from "./WebGridValidationStateDescriptionMetadata";
import { WebRecordValidationStateDescription } from "./WebRecordValidationStateDescription";
/**
 * @hidden
 */
export let WebRecordValidationStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRecordValidationStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebRecordValidationStateDescriptionMetadata.a == null) {
                WebRecordValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRecordValidationStateDescriptionMetadata.c(WebRecordValidationStateDescriptionMetadata.a);
            }
            if (a.j(WebRecordValidationStateDescriptionMetadata.a)) {
                return;
            }
            a.y(WebRecordValidationStateDescriptionMetadata.a);
            WebFieldValidationStateDescriptionMetadata.d(a);
        }
        static c(a) {
            WebGridValidationStateDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RecordValidationState");
            a.item("__packageNameWC", "String:grids");
            a.item("__isPlainObject", "Boolean");
            a.item("Key", "Unknown");
            a.item("Fields", "Array:WebFieldValidationStateDescription:FieldValidationState");
        }
        static d(a) {
            WebRecordValidationStateDescriptionMetadata.b(a);
            a.aa("WebRecordValidationState", () => new WebRecordValidationStateDescription());
            a.z("WebRecordValidationState", WebRecordValidationStateDescriptionMetadata.a);
        }
    }
    WebRecordValidationStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRecordValidationStateDescriptionMetadata, 'WebRecordValidationStateDescriptionMetadata');
    WebRecordValidationStateDescriptionMetadata.a = null;
    return WebRecordValidationStateDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/WebRecordValidationStateDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebFieldValidationStateDescriptionMetadata } from "./WebFieldValidationStateDescriptionMetadata";
import { WebGridValidationStateDescriptionMetadata } from "./WebGridValidationStateDescriptionMetadata";
import { WebRecordValidationStateDescription } from "./WebRecordValidationStateDescription";
/**
 * @hidden
 */
export let WebRecordValidationStateDescriptionMetadata = /*@__PURE__*/ (() => {
    class WebRecordValidationStateDescriptionMetadata extends Base {
        static b(a) {
            if (WebRecordValidationStateDescriptionMetadata.a == null) {
                WebRecordValidationStateDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                WebRecordValidationStateDescriptionMetadata.c(WebRecordValidationStateDescriptionMetadata.a);
            }
            if (a.k(WebRecordValidationStateDescriptionMetadata.a)) {
                return;
            }
            a.aa(WebRecordValidationStateDescriptionMetadata.a);
            WebFieldValidationStateDescriptionMetadata.d(a);
        }
        static c(a) {
            WebGridValidationStateDescriptionMetadata.c(a);
            a.item("__qualifiedNameTS", "String:RecordValidationState");
            a.item("__packageNameWC", "String:grids");
            a.item("__skipModuleRegisterWebComponents", "Boolean");
            a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
            a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
            a.item("__isPlainObject", "Boolean");
            if (a.containsKey("__skipSuffix")) {
                a.removeItem("__skipSuffix");
            }
            a.item("Key", "Unknown");
            a.item("Fields", "Array:WebFieldValidationStateDescription:FieldValidationState");
        }
        static d(a) {
            WebRecordValidationStateDescriptionMetadata.b(a);
            a.ac("WebRecordValidationState", () => new WebRecordValidationStateDescription());
            a.ab("WebRecordValidationState", WebRecordValidationStateDescriptionMetadata.a);
        }
    }
    WebRecordValidationStateDescriptionMetadata.$t = /*@__PURE__*/ markType(WebRecordValidationStateDescriptionMetadata, 'WebRecordValidationStateDescriptionMetadata');
    WebRecordValidationStateDescriptionMetadata.a = null;
    return WebRecordValidationStateDescriptionMetadata;
})();
